@@ -100,9 +100,6 @@ static NGLogger *debugLogger       = nil;
 static NGLogger *perfLogger        = nil;
 static NGLogger *transActionLogger = nil;
 
-+ (int)version {
-  return 2;
-}
 + (void)initialize {
   NSUserDefaults  *ud;
   NGLoggerManager *lm;
@@ -198,8 +195,8 @@ static NGLogger *transActionLogger = nil;
   if (perfLogger) {
       struct timeval tv;
       gettimeofday(&tv, NULL);
-      self->t = (((double)tv.tv_sec) * ((double)tv.tv_usec) / 1000.0)  - 
-        self->t;
+      self->t = (((double)tv.tv_sec) + ((double)tv.tv_usec)
+                 / 1000000.0) - self->t;
       [perfLogger logWithFormat:@"processing of request took %4.3fs.", 
 	                  self->t < 0.0 ? -self->t : self->t];
   }
@@ -326,15 +323,26 @@ static int logCounter = 0;
   if ([woRequest headerForKey:@"x-webobjects-remote-host"] == nil) {
     id<NGSocketAddress> remote = nil;
     NSString *remoteHost = nil;
+
+    /* Use de facto standard headers if remote-host is not set
+     * before falling back to the remote end of the socket 
+     */
+     if ([woRequest headerForKey:@"x-forward"]) {
+       remoteHost = [woRequest headerForKey:@"x-forward"];
+     }
+     else if ([woRequest headerForKey:@"x-forwarded-for"]) {
+       remoteHost = [woRequest headerForKey:@"x-forwarded-for"];
+     }
+     else {
+       remote = [self->socket remoteAddress];
     
-    remote = [self->socket remoteAddress];
-    
-    if ([remote isKindOfClass:[NGInternetSocketAddress class]])
-      remoteHost = [(NGInternetSocketAddress *)remote hostName];
+       if ([remote isKindOfClass:[NGInternetSocketAddress class]])
+         remoteHost = [(NGInternetSocketAddress *)remote hostName];
 #if !defined(__MINGW32__)
-    else if ([remote isKindOfClass:[NGLocalSocketAddress class]])
-      remoteHost = @"local";
+       else if ([remote isKindOfClass:[NGLocalSocketAddress class]])
+         remoteHost = @"local";
 #endif
+    }
 
     if ([remoteHost length] > 0)
       [woRequest setHeader:remoteHost forKey:@"x-webobjects-remote-host"];
@@ -350,11 +358,14 @@ static int logCounter = 0;
         auth =
           [NGHttpCredentials credentialsWithString:[auth stringValue]];
       }
-            
-      [woRequest setHeader:[auth userName]
-                 forKey:@"x-webobjects-remote-user"];
-      [woRequest setHeader:[auth scheme]
-                 forKey:@"x-webobjects-auth-type"];
+       
+      if ([auth userName])
+        [woRequest setHeader:[auth userName]
+                      forKey:@"x-webobjects-remote-user"];
+      
+      if ([auth scheme])
+        [woRequest setHeader:[auth scheme]
+                      forKey:@"x-webobjects-auth-type"];
     }
   }
 }
