@@ -77,10 +77,6 @@
 
 @implementation WOResourceManager
 
-+ (int)version {
-  return 4;
-}
-
 static Class    UrlClass             = Nil;
 static NSString *resourcePrefix      = @"";
 static NSString *rapidTurnAroundPath = nil;
@@ -924,7 +920,6 @@ _pathExists(WOResourceManager *self, NSFileManager *fm, NSString *path)
 {
   // TODO: this method is definitely too big! => refacture
   WOApplication         *app;
-  NSFileManager         *fm            = nil;
   WOComponentDefinition *cdef          = nil;
   NSURL                 *componentURL;
   NSURL                 *appUrl;
@@ -956,8 +951,6 @@ _pathExists(WOResourceManager *self, NSFileManager *fm, NSString *path)
     return cdef;
   }
   
-  fm = [self fileManager];
-  
   /* ensure that the component exists */
 
   if ([componentURL isFileURL]) {
