@@ -415,7 +415,7 @@ static inline BOOL isTokStopChar(unichar c) {
   unsigned slen;
   NSString *entityName;
   BOOL isShallow = NO;
-  BOOL isDeep    = NO;
+  // BOOL isDeep    = NO;
   
   if (_scope)  *_scope  = nil;
   if (_entity) *_entity = nil;
@@ -437,10 +437,12 @@ static inline BOOL isTokStopChar(unichar c) {
     isShallow = YES;
   else if ([self parseToken:(const unsigned char *)"HIERARCHICAL" 
 		 from:&scur length:&slen consume:YES])
-    isDeep = YES;
+    ;
+    // isDeep = YES;
   else if ([self parseToken:(const unsigned char *)"DEEP" 
 		 from:&scur length:&slen consume:YES])
-    isDeep = YES;
+    ;
+    // isDeep = YES;
   else
     /* unknown traveral key */
     return NO;
@@ -488,7 +490,6 @@ static inline BOOL isTokStopChar(unichar c) {
   BOOL hasSelect = NO;
   BOOL hasFrom   = NO;
   BOOL missingByOfOrder = NO;
-  BOOL missingByOfGroup = NO;
   
   *result = nil;
   
@@ -587,7 +588,6 @@ static inline BOOL isTokStopChar(unichar c) {
     if (![self parseToken:(const unsigned char *)"BY" 
 	       from:pos length:len consume:YES]) {
       if (beStrict) return NO;
-      missingByOfGroup = YES;
     }
   }
   
@@ -611,16 +611,16 @@ static inline BOOL isTokStopChar(unichar c) {
   }
   if (orderList) {
     NSMutableArray *ma;
-    unsigned i, len;
+    unsigned len;
     
     len = [orderList count];
     ma = [[NSMutableArray alloc] initWithCapacity:len];
-    for (i = 0; i < len; i++) {
-      EOSortOrdering *so;
+    // for (i = 0; i < len; i++) {
+    //   EOSortOrdering *so;
       
-      so = [EOSortOrdering sortOrderingWithKey:[orderList objectAtIndex:i]
-			   selector:EOCompareAscending];
-    }
+    //   so = [EOSortOrdering sortOrderingWithKey:[orderList objectAtIndex:i]
+    //     		   selector:EOCompareAscending];
+    // }
     lSortOrderings = [ma shallowCopy];
     [ma release];
     [orderList release]; orderList = nil;
