@@ -118,6 +118,7 @@ static int openConnectionCount = 0;
   const char *cDBName;
   MySQL4Adaptor *adaptor;
   NSString *host, *socket;
+  BOOL reconnect;
   void *rc;
   
   if (self->_connection != NULL) {
@@ -154,6 +155,9 @@ static int openConnectionCount = 0;
   else
     socket = nil;
   
+  reconnect = YES;
+  mysql_options(self->_connection, MYSQL_OPT_RECONNECT, &reconnect);
+
   rc = mysql_real_connect(self->_connection, 
 			  [host UTF8String],
 			  [[adaptor loginName]     UTF8String],
