@@ -30,15 +30,6 @@
 
 @implementation NGLdapFileManager
 
-+ (int)version {
-  return [super version] + 0 /* v0 */;
-}
-+ (void)initialize {
-  NSAssert2([super version] == 0,
-            @"invalid superclass (%@) version %i !",
-            NSStringFromClass([self superclass]), [super version]);
-}
-
 static NSString *LDAPObjectClassKey = @"objectclass";
 static NSArray  *objectClassAttrs = nil;
 static NSArray  *fileInfoAttrs    = nil;
