@@ -816,7 +816,7 @@ static int FetchNewUnseenMessagesInSubFoldersOnDemand = -1;
   // TODO: using 'lastObject' is certainly wrong? need to search for body
   result = [fetchResults lastObject];
   
-  if ((result = [result objectForKey:@"body"]) == nil)
+  if ((result = [result objectForKey: _part ? bodyKey : @"body"]) == nil)
     [self debugWithFormat:@"found no body in fetch results: %@", fetchResults];
   
   return [result objectForKey:@"data"];
@@ -1116,11 +1116,10 @@ static int FetchNewUnseenMessagesInSubFoldersOnDemand = -1;
 }
 
 - (void)initializeSubFolders {
-  NSString     *n;
   NSEnumerator *folders;
   NSDictionary *res;
   id           folder, *objs;
-  unsigned     cnt, nl;
+  unsigned     cnt;
   BOOL         showSubsrcFolders;
   NSString     *pattern;
   
@@ -1157,10 +1156,6 @@ static int FetchNewUnseenMessagesInSubFoldersOnDemand = -1;
   }
   
   cnt = 0;
-  if (showSubsrcFolders) {
-    n  = [self absoluteName];
-    nl = [n length];
-  }
   
   while ((folder = [folders nextObject])) {
     NGImap4Folder *newFolder;
