@@ -40,6 +40,10 @@ static unsigned int _decodeOfModifiedUTF7(unsigned char *_source, unichar *resul
   unsigned int  cntRes  = 0;
   NSString      *result = nil;
 
+  /* do real work only if we're not already 7bit safe */
+  if ([self is7bitSafe])
+    return [[self copy] autorelease];
+
   len = [self length];
   buf = NSZoneMalloc(NULL, (len + 1) * sizeof(unichar));
   [self getCharacters: buf];
@@ -246,4 +250,22 @@ static unsigned int _decodeOfModifiedUTF7(unsigned char *_source, unichar *resul
   return processedSrc;
 }
 
+- (BOOL) is7bitSafe
+{
+  int i, len;
+
+  // We search for a non-ASCII character.
+  len = [self length];
+
+  for (i = 0; i < len; i++)
+    {
+      if ([self characterAtIndex: i] > 0x007E)
+        {
+          return NO;
+        }
+    }
+
+  return YES;
+}
+
 @end /* NSString(Imap4) */
