@@ -27,10 +27,6 @@
 
 @implementation NGMimeBodyPart
 
-+ (int)version {
-  return 2;
-}
-
 + (id)bodyPartWithHeader:(NGHashMap *)_header {
   return [[[self alloc] initWithHeader:_header] autorelease];
 }
